import java.net.*;
import java.io.*;

/**
 * Represents a single thread.  Creates a new instance
 * of the GraffitiProtocol class to handle the conversation
 * between client and this thread.
 * 
 * @see GraffitiProtocol
 */
public class GraffitiServerThread extends Thread
{
    private Socket socket = null;

	/**
	 * Gets the socket from the GraffitiServer instance
	 */
    public GraffitiServerThread(Socket socket) 
	{
		super("GraffitServerThread");
		this.socket = socket;
    }

	/**
	 * Creates a new instance of the GraffitiProtocol and
	 * processes the conversation with the client until
	 * the client says "BYE" or the we get an abnormal
	 * termination of the client.  In both cases, we simply
	 * let the thread finish and the server keeps running.
	 */
	public void run() {
		try {
			PrintWriter out = new PrintWriter(socket.getOutputStream(), true);
			BufferedReader in = new BufferedReader(new InputStreamReader(socket.getInputStream()));
			String inputLine, outputLine;
			
			// create instance of graffitiProtocol which will
			// handle all communication between server and client
			GraffitiProtocol gcp = new GraffitiProtocol();

			// process conversation
			while (gcp.isConnected) {
				gcp.processInput(in, out);
			}
		
			out.close();
			in.close();
			socket.close();

		} catch (IOException e) {
			// must keep server alive if something happened to the client
			// just let the thread die.					
		}
    }
}